==> nezha-engine-api-1.0.90-lrb-20190929.100629-3-sources.jar: cn/com/duiba/nezha/engine/api/enums/RedisKey.java <==
package cn.com.duiba.nezha.engine.api.enums;

/**
 * @author ElinZhou
 * @version $Id: RedisKey.java , v 0.1 2017/5/19 下午4:38 ElinZhou Exp $
 */
public enum RedisKey {

    /**
     * CPA广告点击计数
     */
    K37,


    /**
     * CPA广告计费累计
     */
    K38,


    /**
     * CPA广告转换次数累计
     */
    K39,


    /**
     * CPA广告点击分布式锁
     */
    K40,


    /**
     * CPA广告后端转换次数累计
     */
    K41,


    /**
     * 素材曝光累计
     */
    K42,


    /**
     * CPA最近点击记录
     */
    K43,


    /**
     * 标签对应的广告列表
     */
    KC119,

    /**
     * 广告统计特征
     */
    K44,

    /**
     * 广告素材排名
     */
    K045,

    /**
     * 广告融合统计数据
     */
    K46,

    /**
     * 广告分日统计数据
     */
    K47,

    /**
     * 广告分时统计数据
     */
    K48,

    /**
     * 广告调价因子key
     */
    K55,

    /**
     * 标签下的cvr分日数据
     */
    K60,

    /**
     * 标签下的cvr分时数据
     */
    K61,

    /**
     * 哪吒统计纠偏
     */
    K66,

    /**
     * 哪吒统计纠偏
     */
    K67,

    /**
     * 哪吒统计纠偏
     */
    K68,

    /**
     * 黑白名单
     */
    K73,

    /**
     * 新黑白名单数据
     */
    K75,

    /**
     * 候选集
     */
    K76,

    /**
     * 广告主预算消耗
     */
    K78,

    /**
     * 广告配置+媒体预算消耗信息
     */
    K79,

    /**
     * 广告配置+时段
     */
    K80,
    /**
     * 广告配置预算消耗
     */
    K81,
    /**
     * 广告消耗
     */
    K82,
    /**
     * 活动特征
     */
    K83,

    /**
     * 广告位上配置包的信息
     */
    K84,

    K85,

    /**
     * 全局配置的key
     */
    K86,

    /**
     * 新广告扶持数据
     */
    K87,

    /**
     * 广告位的新广告扶持数据
     */
    K88,

    /**
     * 托管的广告数据
     */
    K89,

    /**
     * 新预算平滑
     */
    K90,

    /**
     * (算法业务)托管的广告次数
     */
    K91,

    /**
     * (算法业务)托管自救全维度
     */
    K92,

    /**
     * (算法业务)托管自救媒体维度
     */
    K93,

    /**
     * (算法业务)托管自救广告位维度
     */
    K94,
    /**
     *  底价放弃实时数据
     */
    K95,

    /**
     * k96-99已经被占用，只是暂时还没开发
     */

    /**
     * 用于CPC自动竞价的数据
     */
    K100
    ;
}

==> nezha-engine-api-1.0.95-lrb-20191202.063053-1-sources.jar: cn/com/duiba/nezha/engine/api/enums/RedisKey.java <==
package cn.com.duiba.nezha.engine.api.enums;

/**
 * @author ElinZhou
 * @version $Id: RedisKey.java , v 0.1 2017/5/19 下午4:38 ElinZhou Exp $
 */
public enum RedisKey {

    /**
     * CPA广告点击计数
     */
    K37,


    /**
     * CPA广告计费累计
     */
    K38,


    /**
     * CPA广告转换次数累计
     */
    K39,


    /**
     * CPA广告点击分布式锁
     */
    K40,


    /**
     * CPA广告后端转换次数累计
     */
    K41,


    /**
     * 素材曝光累计
     */
    K42,


    /**
     * CPA最近点击记录
     */
    K43,


    /**
     * 标签对应的广告列表
     */
    KC119,

    /**
     * 广告统计特征
     */
    K44,

    /**
     * 广告素材排名
     */
    K045,

    /**
     * 广告融合统计数据
     */
    K46,

    /**
     * 广告分日统计数据
     */
    K47,

    /**
     * 广告分时统计数据
     */
    K48,

    /**
     * 广告调价因子key
     */
    K55,

    /**
     * 标签下的cvr分日数据
     */
    K60,

    /**
     * 标签下的cvr分时数据
     */
    K61,

    /**
     * 哪吒统计纠偏
     */
    K66,

    /**
     * 哪吒统计纠偏
     */
    K67,

    /**
     * 哪吒统计纠偏
     */
    K68,

    /**
     * 黑白名单
     */
    K73,

    /**
     * 新黑白名单数据
     */
    K75,

    /**
     * 候选集
     */
    K76,

    /**
     * 广告主预算消耗
     */
    K78,

    /**
     * 广告配置+媒体预算消耗信息
     */
    K79,

    /**
     * 广告配置+时段
     */
    K80,
    /**
     * 广告配置预算消耗
     */
    K81,
    /**
     * 广告消耗
     */
    K82,
    /**
     * 活动特征
     */
    K83,

    /**
     * 广告位上配置包的信息
     */
    K84,

    K85,

    /**
     * 全局配置的key
     */
    K86,

    /**
     * 新广告扶持数据
     */
    K87,

    /**
     * 广告位的新广告扶持数据
     */
    K88,

    /**
     * 托管的广告数据
     */
    K89,

    /**
     * 新预算平滑
     */
    K90,

    /**
     * (算法业务)托管的广告次数
     */
    K91,

    /**
     * (算法业务)托管自救全维度
     */
    K92,

    /**
     * (算法业务)托管自救媒体维度
     */
    K93,

    /**
     * (算法业务)托管自救广告位维度
     */
    K94,
    /**
     *  底价放弃实时数据
     */
    K95,

    /**
     *  广告&媒体画像泛化特征-广告行业
     */
    K96,

    /**
     *  广告&媒体画像泛化特征-媒体行业
     */
    K97,

    /**
     *  广告&媒体画像泛化特征-媒体ID
     */
    K98,

    /**
     *  广告&媒体画像泛化特征-广告ID
     */
    K99,

    /**
     * 用于CPC自动竞价的数据
     */
    K100,

    /**
     * 算法给的配置人群标签
     */
    K101,

    /**
     * 广告&配置&人群标签实时数据
     */
    K102,
    ;
}
